@@ -1,6 +1,7 @@
 library(rcbalance)
 library(rcbsubset)
-library(optmatch)
+if (requireNamespace("optmatch", quietly = TRUE)){
+  library(optmatch)
 context('Excluding treated units')
 
 data(nuclearplants)
@@ -33,4 +34,5 @@ test_that('Matches with one pair are returned correctly', {
 	match.out <- rcbsubset(dist.struct2, fb.list = list('ct'), treated.info = nuclearplants[10,], control.info = nuclearplants[nuclearplants$pr == 0,])
 	expect_equal(rownames(match.out$matches), '1')
 	expect_equal(dim(match.out$fb.tables[[1]]), c(1,2))
-})
\ No newline at end of file
+})
+}
\ No newline at end of file
